pkg

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 11, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the pkg type in the database.
	Label = "pkg"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldPkgPath holds the string denoting the pkg_path field in the database.
	FieldPkgPath = "pkg_path"
	// FieldIsInternal holds the string denoting the is_internal field in the database.
	FieldIsInternal = "is_internal"
	// Table holds the table name of the pkg in the database.
	Table = "pkgs"
)

Variables

var (
	// PkgPathValidator is a validator for the "pkg_path" field. It is called by the builders before save.
	PkgPathValidator func(string) error
	// DefaultIsInternal holds the default value on creation for the "is_internal" field.
	DefaultIsInternal bool
)

Columns holds all SQL columns for pkg fields.

Functions

func And

func And(predicates ...predicate.Pkg) predicate.Pkg

And groups predicates with the AND operator between them.

func ID

func ID(id int) predicate.Pkg

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Pkg

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Pkg

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Pkg

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Pkg

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Pkg

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Pkg

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Pkg

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Pkg

IDNotIn applies the NotIn predicate on the ID field.

func IsInternal

func IsInternal(v bool) predicate.Pkg

IsInternal applies equality check predicate on the "is_internal" field. It's identical to IsInternalEQ.

func IsInternalEQ

func IsInternalEQ(v bool) predicate.Pkg

IsInternalEQ applies the EQ predicate on the "is_internal" field.

func IsInternalNEQ

func IsInternalNEQ(v bool) predicate.Pkg

IsInternalNEQ applies the NEQ predicate on the "is_internal" field.

func Not

func Not(p predicate.Pkg) predicate.Pkg

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Pkg) predicate.Pkg

Or groups predicates with the OR operator between them.

func PkgPath

func PkgPath(v string) predicate.Pkg

PkgPath applies equality check predicate on the "pkg_path" field. It's identical to PkgPathEQ.

func PkgPathContains

func PkgPathContains(v string) predicate.Pkg

PkgPathContains applies the Contains predicate on the "pkg_path" field.

func PkgPathContainsFold

func PkgPathContainsFold(v string) predicate.Pkg

PkgPathContainsFold applies the ContainsFold predicate on the "pkg_path" field.

func PkgPathEQ

func PkgPathEQ(v string) predicate.Pkg

PkgPathEQ applies the EQ predicate on the "pkg_path" field.

func PkgPathEqualFold

func PkgPathEqualFold(v string) predicate.Pkg

PkgPathEqualFold applies the EqualFold predicate on the "pkg_path" field.

func PkgPathGT

func PkgPathGT(v string) predicate.Pkg

PkgPathGT applies the GT predicate on the "pkg_path" field.

func PkgPathGTE

func PkgPathGTE(v string) predicate.Pkg

PkgPathGTE applies the GTE predicate on the "pkg_path" field.

func PkgPathHasPrefix

func PkgPathHasPrefix(v string) predicate.Pkg

PkgPathHasPrefix applies the HasPrefix predicate on the "pkg_path" field.

func PkgPathHasSuffix

func PkgPathHasSuffix(v string) predicate.Pkg

PkgPathHasSuffix applies the HasSuffix predicate on the "pkg_path" field.

func PkgPathIn

func PkgPathIn(vs ...string) predicate.Pkg

PkgPathIn applies the In predicate on the "pkg_path" field.

func PkgPathLT

func PkgPathLT(v string) predicate.Pkg

PkgPathLT applies the LT predicate on the "pkg_path" field.

func PkgPathLTE

func PkgPathLTE(v string) predicate.Pkg

PkgPathLTE applies the LTE predicate on the "pkg_path" field.

func PkgPathNEQ

func PkgPathNEQ(v string) predicate.Pkg

PkgPathNEQ applies the NEQ predicate on the "pkg_path" field.

func PkgPathNotIn

func PkgPathNotIn(vs ...string) predicate.Pkg

PkgPathNotIn applies the NotIn predicate on the "pkg_path" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Pkg queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsInternal

func ByIsInternal(opts ...sql.OrderTermOption) OrderOption

ByIsInternal orders the results by the is_internal field.

func ByPkgPath

func ByPkgPath(opts ...sql.OrderTermOption) OrderOption

ByPkgPath orders the results by the pkg_path field.

Jump to